@@ -69,6 +69,7 @@ struct _Slide2AnswerStatusPluginPrivate
   GtkWidget* call_window_number_label;
   GtkWidget* call_window_slider;
   gboolean is_voip_call;
+  guint slider_handler_id;
   DBusGConnection *dbus_system_conn;
   DBusGProxy *dbus_system_proxy;
   OssoABookAggregator* abook_aggregator;
@@ -160,15 +161,18 @@ _accept_call(Slide2AnswerStatusPlugin* plugin)
   plugin->priv->active_channel = NULL;
 }
 
-static gboolean
+static void
 _slider_changed(GtkRange* range,
-		GtkScrollType scroll,
-		gdouble value,
+		/*		GtkScrollType scroll,
+				gdouble value,*/
 		gpointer user_data)
 {
   if(IS_SLIDE2ANSWER_STATUS_PLUGIN(user_data))
   {
+
     Slide2AnswerStatusPlugin* plugin = SLIDE2ANSWER_STATUS_PLUGIN(user_data);
+    double value = gtk_range_get_value(GTK_RANGE(plugin->priv->call_window_slider));
+    g_warning("value changed\n");
     if(value>0.9)
     {
       gtk_widget_hide(GTK_WIDGET(plugin->priv->call_window));
@@ -179,33 +183,19 @@ _slider_changed(GtkRange* range,
       gtk_widget_hide(GTK_WIDGET(plugin->priv->call_window));
       _reject_call(plugin);
     }
+    else
+    {
+      gtk_range_set_value(GTK_RANGE(plugin->priv->call_window_slider), 0.0);
+    }
   }
-  return FALSE;
-}
 
-static gboolean
-_slider_changed_stopped(GtkWidget *widget,
-			GdkEventButton *event,
-			gpointer user_data)
-{
-  if(GTK_IS_RANGE(user_data))
-  {
-    gtk_range_set_value(GTK_RANGE(user_data), 0.0);
-  }
-  return FALSE;
 }
 
 static void
 _create_slide2answer_window(Slide2AnswerStatusPlugin* status_plugin)
 {
   status_plugin->priv->call_window = hildon_window_new();//gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  /*
-  GdkPixbuf* pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
-					       "general_default_avatar",
-					       AVATAR_SIZE, GTK_ICON_LOOKUP_NO_SVG, NULL);
-  */
-  //  status_plugin->priv->call_window_avatar = gtk_image_new_from_pixbuf(pixbuf);
-  
+
   status_plugin->priv->call_window_avatar = osso_abook_avatar_image_new();
 
   osso_abook_avatar_image_set_fallback_icon(OSSO_ABOOK_AVATAR_IMAGE(status_plugin->priv->call_window_avatar),
@@ -215,13 +205,11 @@ _create_slide2answer_window(Slide2AnswerStatusPlugin* status_plugin)
   hildon_helper_set_logical_font(status_plugin->priv->call_window_name_label, "LargeSystemFont");
   status_plugin->priv->call_window_number_label = gtk_label_new("");
   hildon_helper_set_logical_font(status_plugin->priv->call_window_number_label, "SmallSystemFont");
-  
-  status_plugin->priv->call_window_slider = hildon_gtk_hscale_new();
-  //gtk_range_set_jump_to_position(GTK_RANGE(status_plugin->priv->call_window_slider), FALSE);
-  gtk_widget_set_name(status_plugin->priv->call_window_slider,
-		      "bidirectional-slider-horizontal");
+
+  status_plugin->priv->call_window_slider = hildon_gtk_hscale_new();  
   gtk_range_set_range(GTK_RANGE(status_plugin->priv->call_window_slider), -1.0, 1.0);              
   gtk_range_set_value(GTK_RANGE(status_plugin->priv->call_window_slider), 0.0);
+  gtk_range_set_update_policy(GTK_RANGE(status_plugin->priv->call_window_slider), GTK_UPDATE_DISCONTINUOUS);
   gtk_widget_set_name(status_plugin->priv->call_window_slider,
 		      "sui-tklock-slider");
   
@@ -237,12 +225,7 @@ _create_slide2answer_window(Slide2AnswerStatusPlugin* status_plugin)
   gtk_widget_set_name(reject_button, "hildon-reject-button-thumb");
   gtk_widget_set_sensitive(accept_button, FALSE);
   gtk_widget_set_sensitive(reject_button, FALSE);
-  /*
-  gtk_range_set_update_policy(GTK_RANGE(status_plugin->priv->call_window_slider),
-			      GTK_UPDATE_DELAYED);
-  */
-  g_signal_connect(status_plugin->priv->call_window_slider, "change-value", G_CALLBACK(_slider_changed), status_plugin);
-  g_signal_connect(status_plugin->priv->call_window_slider, "button-release-event", G_CALLBACK(_slider_changed_stopped), status_plugin->priv->call_window_slider);
+  status_plugin->priv->slider_handler_id = g_signal_connect(status_plugin->priv->call_window_slider, "value-changed", G_CALLBACK(_slider_changed), status_plugin);
 
   GtkWidget* contact_box = gtk_hbox_new(FALSE, 0);
   GtkWidget* contact_info_box = gtk_vbox_new(FALSE, 0);
@@ -309,10 +292,11 @@ _show_slide2answer_window(Slide2AnswerStatusPlugin* plugin)
   }
   else
   {
+    g_signal_handler_block(plugin->priv->call_window_slider, plugin->priv->slider_handler_id);
     gtk_range_set_value(GTK_RANGE(plugin->priv->call_window_slider), 0.0);
+    g_signal_handler_unblock(plugin->priv->call_window_slider, plugin->priv->slider_handler_id);
     gtk_widget_show_all(GTK_WIDGET(plugin->priv->call_window));
   }
-
   _set_call_ui_orientation_mode(plugin);
 }
 
@@ -421,8 +405,9 @@ handle_new_channel(TpConnection *proxy,
 		   gpointer user_data,
 		   GObject *weak_object)
 {
+
   if(arg_Suppress_Handler || 
-     g_strcmp0(arg_Channel_Type, "org.freedesktop.Telepathy.Channel.Type.Text") == 0)
+     g_strcmp0(arg_Channel_Type, "org.freedesktop.Telepathy.Channel.Type.StreamedMedia") != 0)
     return;
   
   Slide2AnswerStatusPlugin* plugin = SLIDE2ANSWER_STATUS_PLUGIN(user_data);
